@@ -3,7 +3,7 @@ BEGIN {
   $IRC::Utils::AUTHORITY = 'cpan:HINRIK';
 }
 BEGIN {
-  $IRC::Utils::VERSION = '0.01';
+  $IRC::Utils::VERSION = '0.02';
 }
 
 use strict;
@@ -233,7 +233,8 @@ sub matches_mask_array {
 
 sub matches_mask {
     my ($mask, $match, $mapping) = @_;
-    return if !defined $mask || !defined $match;
+    return if !defined $mask || !length $mask;
+    return if !defined $match || !length $match;
 
     $mask = parse_ban_mask($mask);
     $mask =~ s/\*+/*/g;
